==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/additionalelements/e2detector/inspect/length/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot, ['--gui-testing-debug-gl'])

# go to additional mode
netedit.additionalMode()

# select E2
netedit.changeElement("laneAreaDetector")

# create E2
netedit.leftClick(referencePosition, 250, 130)

# go to inspect mode
netedit.inspectMode()

# inspect first E2
netedit.leftClick(referencePosition, 350, 130)

# Change parameter length with a non valid value(dummy)
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "dummyLength", True)

# Change parameter length with a non valid value (negative)
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "-5", True)

# Change parameter length with a non valid value (0)
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "0", True)

# Change parameter length with a valid value (> lane length)
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "500", True)

# Change parameter length with a valid value
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "5", True)

# Check undos and redos
netedit.undo(referencePosition, 2)
netedit.redo(referencePosition, 2)

# save additionals
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/additionalelements/e2detector/inspect/length/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to additional mode
netedit.additionalMode()

# select E2
netedit.changeElement("laneAreaDetector")

# create E2
netedit.leftClick(referencePosition, 520, 210)

# go to inspect mode
netedit.inspectMode()

# inspect first E2
netedit.leftClick(referencePosition, 480, 210)

# Change parameter length with a non valid value(dummy)
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "dummyLength", True)

# Change parameter length with a non valid value (negative)
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "-5", True)

# Change parameter length with a non valid value (0)
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "0", True)

# Change parameter length with a valid value (> lane length)
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "500", True)

# Change parameter length with a valid value
netedit.modifyAttribute(netedit.attrs.E2.inspect.length, "5", True)

# Check undos and redos
netedit.undo(referencePosition, 2)
netedit.redo(referencePosition, 2)

# save netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
